import { Subject, Observable } from 'rxjs';
import { IBucketItemRef, BucketDOMRectBound } from './types';
/**
 * 한개의 버킷 아이템
 * @export
 * @class JdBucketItemRef
 * @implements {IBucketItemRef}
 */
export declare class JdBucketItemRef<TM = any> implements IBucketItemRef<TM> {
    constructor();
    protected uid: string;
    protected elDragContainer: Element | null;
    protected dataModel: TM | null;
    protected selected: boolean;
    protected subjectChangeState: Subject<any>;
    /**
     * 해당 아이템에 등록된 모델
     * @readonly
     */
    get model(): TM | null;
    /**
     * 아이템의 (드래깅)선택 여부
     * @readonly
     */
    get isSelected(): boolean;
    /**
     * draggable 에서 사용되는 DOM
     * (draggable 의 이벤트 등에서 DOM 을 clone 하거나 target DOM 등 으로 사용됨)
     * @readonly
     * @type {(Element | null)}
     */
    get elContainer(): Element | null;
    /**
     * 해당 아이템과 연결할 모델.
     * @param {TM} model
     */
    setModel(model: TM): void;
    /**
     * draggable DOM 참조 지정.
     * @param {Element} element
     */
    setElContainer(element: Element): void;
    /**
     * 해당 아이템의 선택(드래깅) 상태 지정.
     * @param {boolean} is
     */
    setSelected(is: boolean): void;
    /**
     * 해당 아이템의 uid 반환
     * @returns {string}
     */
    getUid(): string;
    /**
     * 해당 아이템의 DOM 의 bound 영역.
     * @returns {DOMRectBound | null}
     */
    getElBound(): BucketDOMRectBound | null;
    /**
     * 옵저버: 아이템 상태.
     * @returns {Observable<any>}
     */
    observeChangeState(): Observable<any>;
    /**
     * 알림: 아이템 상태 변경.
     */
    dispatchChangeState(): void;
    /**
     * 파기
     *
     */
    destroy(): void;
}
