import { Subject, Observable } from 'rxjs';
import { BucketDragStart, BucketEvent, BucketDragEnd, IBucketContainerRef, IBucketRef, BucketDragChoose, BucketRangeSelectionEvent } from './types';
/**
 * 버킷 최상위 관리
 * @export
 * @class JdBucketRef
 * @implements {IBucketRef}
 */
export declare class JdBucketRef implements IBucketRef {
    constructor();
    protected containerRefMap: Map<string, IBucketContainerRef>;
    protected subjectDragger: Subject<BucketEvent>;
    protected subjectRangeSelection: Subject<BucketRangeSelectionEvent>;
    protected draggingContainerRef: IBucketContainerRef | null;
    protected fallbackIndicate: boolean;
    /**
     * dnd 폴백을 사용하는지 여부
     * @readonly
     * @type {boolean}
     */
    get isFallbackIndicate(): boolean;
    /**
     * dnd 폴백을 사용하는지 여부 지정.
     * 폴백을 사용하지 않는 다면 브라우저에서 기본으로 지원하는 드래그(중인 이미지) UI 를 사용하고,
     * 폴백을 사용한다면 DOM 을 이용하는데, draggable 에서 사용하는 폴백 DOM 을 invisible 처리하고,
     * draggable 대신 드래그 중인 UI 를 표시한다.
     * @param {boolean} is
     */
    setFallbackIndicate(is: boolean): void;
    /**
     *
     * 등록된 버킷 컨테이너 맵.
     * @returns {Map<string, IBucketContainerRef>}
     */
    getContainerRefs(): Map<string, IBucketContainerRef>;
    /**
     * 옵저버: 드래그 상태
     * @returns {Observable<BucketEvent>}
     */
    observeDragger(): Observable<BucketEvent>;
    /**
     * 옵저버: 영역 선택기 상태
     * @returns {Observable<BucketRangeSelectionEvent>}
     */
    observeRangeSelection(): Observable<BucketRangeSelectionEvent>;
    /**
     * 알림: 드래그 아이템 선택
     * @param {BucketDragChoose} params
     */
    dispatchDragChoose(params: BucketDragChoose): void;
    /**
     * 알림: 드래그 아이템 선택 해제
     * @param {BucketDragChoose} params
     */
    dispatchDragUnchoose(params: BucketDragChoose): void;
    /**
     * 알림: 드래그 시작
     * @param {BucketDragStart} params
     */
    dispatchDragStart(params: BucketDragStart): void;
    /**
     * 알림: 드래그 종료
     * @param {BucketDragEnd} params
     */
    dispatchDragEnd(params: BucketDragEnd): void;
    /**
     * 알림: 영역 선택기 시작
     * @param {BucketRangeSelectionEvent} params
     */
    dispatchRangeSelectionStart(params: BucketRangeSelectionEvent): void;
    /**
     * 버킷 컨테이너 등록
     * @param {IBucketContainerRef} containerRef
     */
    joinContainerRef(containerRef: IBucketContainerRef): void;
    /**
     * 버킷 컨테이너 등록 해제
     * @param {IBucketContainerRef} containerRef
     */
    unjoinContainerRef(containerRef: IBucketContainerRef): void;
    /**
     * 해당 element(DOM) 가 속한 버킷 컨테이너 찾기
     * @param {Element} element
     * @returns {IBucketContainerRef}
     */
    findContainerRefByElement(element: Element): IBucketContainerRef;
    /**
     * document
     * @returns {Document}
     */
    protected getDocument(): Document;
    /**
     * 키보드 이벤트 핸들러
     * @protected
     */
    protected handleKeyboard: (evt: KeyboardEvent) => void;
    /**
     * 키보드 이벤트 핸들러 등록
     * @protected
     */
    protected addKeyboardListener(): void;
    /**
     * 키보드 이벤트 핸들러 제거
     * @protected
     */
    protected removeKeyboardListener(): void;
    /**
     * 드래그 중 취소
     */
    cancel(): void;
}
